@@ -87,8 +87,9 @@ pub trait WrapperReturnTypeAndError<R: Message, E: StdSyncSendError>: Send + Syn
     fn response(&self, mid: u64, resp: Result<R, Error<(), E>>) -> Result<Option<R>, Error>;
 }
 
+pub type TypeTagAcceptItem = (TypeTag, Option<(TypeTag, TypeTag)>);
 pub trait TypeTagAccept {
-    fn iter_types(&self) -> Box<dyn Iterator<Item = (TypeTag, Option<(TypeTag, TypeTag)>)> + '_>;
+    fn iter_types(&self) -> Box<dyn Iterator<Item = TypeTagAcceptItem> + '_>;
     fn accept_msg(&self, msg: &TypeTag) -> bool;
     fn accept_req(&self, req: &TypeTag, resp: Option<&TypeTag>, err: Option<&TypeTag>) -> bool;
 }
@@ -119,9 +120,11 @@ pub trait ReceiverTrait: TypeTagAccept + Send + Sync {
     fn sync_notify(&self) -> &Notify;
     fn flush_notify(&self) -> &Notify;
     fn ready_notify(&self) -> &Notify;
+    fn idle_notify(&self) -> &Notify;
 
     fn is_init_sent(&self) -> bool;
     fn is_ready(&self) -> bool;
+    fn is_idling(&self) -> bool;
     fn need_flush(&self) -> bool;
     fn set_need_flush(&self);
 
@@ -239,11 +242,15 @@ where
                         }
                         Event::Flushed => {
                             self.context.need_flush.store(false, Ordering::SeqCst);
-                            self.context.flushed.notify_waiters();
+                            self.context.flushed.notify_one();
                         }
                         Event::Synchronized(_res) => self.context.synchronized.notify_waiters(),
                         Event::Response(mid, resp) => {
-                            self.context.processing.fetch_sub(1, Ordering::SeqCst);
+                            let prev_value = self.context.processing.fetch_sub(1, Ordering::SeqCst);
+                            if prev_value == 1  { // last task completes
+                                self.context.idle.notify_waiters();
+                            }
+
                             self.context.response.notify_one();
 
                             match self.response(mid, resp) {
@@ -350,7 +357,7 @@ where
     E: StdSyncSendError,
     S: ReciveTypedReceiver<R, E> + Send + Sync + 'static,
 {
-    fn iter_types(&self) -> Box<dyn Iterator<Item = (TypeTag, Option<(TypeTag, TypeTag)>)> + '_> {
+    fn iter_types(&self) -> Box<dyn Iterator<Item = TypeTagAcceptItem> + '_> {
         Box::new(std::iter::once((
             M::type_tag_(),
             Some((R::type_tag_(), E::type_tag_())),
@@ -385,10 +392,6 @@ where
     E: StdSyncSendError,
     S: SendUntypedReceiver + SendTypedReceiver<M> + ReciveTypedReceiver<R, E> + 'static,
 {
-    fn id(&self) -> u64 {
-        self.id
-    }
-
     fn name(&self) -> &str {
         std::any::type_name::<S>()
     }
@@ -401,6 +404,10 @@ where
         Some(AnyWrapperRef::new(self))
     }
 
+    fn id(&self) -> u64 {
+        self.id
+    }
+
     fn send_boxed(
         &self,
         mid: u64,
@@ -417,6 +424,16 @@ where
             .map_err(|err| err.map_msg(|m| m.into_boxed()))
     }
 
+    fn add_response_listener(
+        &self,
+        listener: oneshot::Sender<Result<Box<dyn Message>, Error>>,
+    ) -> Result<u64, Error> {
+        Ok(self
+            .waiters
+            .insert(Waiter::Boxed(listener))
+            .ok_or(Error::AddListenerError)? as _)
+    }
+
     fn stats(&self) -> Stats {
         Stats {
             msg_type_tag: M::type_tag_(),
@@ -435,10 +452,6 @@ where
         SendUntypedReceiver::send(&self.inner, action, bus)
     }
 
-    fn set_need_flush(&self) {
-        self.context.need_flush.store(true, Ordering::SeqCst);
-    }
-
     fn close_notify(&self) -> &Notify {
         &self.context.closed
     }
@@ -451,32 +464,34 @@ where
         &self.context.flushed
     }
 
-    fn add_response_listener(
-        &self,
-        listener: oneshot::Sender<Result<Box<dyn Message>, Error>>,
-    ) -> Result<u64, Error> {
-        Ok(self
-            .waiters
-            .insert(Waiter::Boxed(listener))
-            .ok_or(Error::AddListenerError)? as _)
-    }
-
     fn ready_notify(&self) -> &Notify {
         &self.context.ready
     }
 
-    fn is_ready(&self) -> bool {
-        self.context.ready_flag.load(Ordering::SeqCst)
+    fn idle_notify(&self) -> &Notify {
+        &self.context.idle
     }
 
     fn is_init_sent(&self) -> bool {
         self.context.init_sent.load(Ordering::SeqCst)
     }
 
+    fn is_ready(&self) -> bool {
+        self.context.ready_flag.load(Ordering::SeqCst)
+    }
+
+    fn is_idling(&self) -> bool {
+        self.context.processing.load(Ordering::SeqCst) == 0
+    }
+
     fn need_flush(&self) -> bool {
         self.context.need_flush.load(Ordering::SeqCst)
     }
 
+    fn set_need_flush(&self) {
+        self.context.need_flush.store(true, Ordering::SeqCst);
+    }
+
     fn try_reserve(&self, _: &TypeTag) -> Option<Permit> {
         loop {
             let count = self.context.processing.load(Ordering::Relaxed);
@@ -506,13 +521,13 @@ where
         self.context.response.clone()
     }
 
-    fn start_polling(self: Arc<Self>) -> BusPollerCallback {
-        self.start_polling_events()
-    }
-
     fn increment_processing(&self, _tt: &TypeTag) {
         self.context.processing.fetch_add(1, Ordering::SeqCst);
     }
+
+    fn start_polling(self: Arc<Self>) -> BusPollerCallback {
+        self.start_polling_events()
+    }
 }
 
 pub struct Permit {
@@ -695,6 +710,7 @@ struct ReceiverContext {
     synchronized: Notify,
     closed: Notify,
     ready: Notify,
+    idle: Notify,
     response: Arc<Notify>,
     init_sent: AtomicBool,
     resend_unused_resp: bool,
@@ -763,6 +779,7 @@ impl Receiver {
                     synchronized: Notify::new(),
                     closed: Notify::new(),
                     ready: Notify::new(),
+                    idle: Notify::new(),
                     response: Arc::new(Notify::new()),
                     resend_unused_resp: resend,
                 }),
@@ -1020,6 +1037,13 @@ impl Receiver {
         }
     }
 
+    #[inline]
+    pub async fn idle(&self) {
+        if !self.inner.is_idling() {
+            self.inner.idle_notify().notified().await;
+        }
+    }
+
     #[inline]
     pub async fn ready(&self) {
         let notify = self.inner.ready_notify().notified();
