@@ -62,12 +62,10 @@ macro_rules! buffer_unordered_poller_macro {
                             semaphore.clone().acquire_owned().await,
                         );
                     }
-                    Request::Action(Action::Init(..)) => {
-                        stx.send(Event::Ready).unwrap();
-                    }
-                    Request::Action(Action::Close) => {
-                        rx.close();
-                    }
+
+                    Request::Action(Action::Init(..)) => stx.send(Event::Ready).unwrap(),
+                    Request::Action(Action::Close) => rx.close(),
+
                     Request::Action(Action::Flush) => {
                         let _ = semaphore.acquire_many(cfg.max_parallel as _).await;
                         stx.send(Event::Flushed).unwrap();
